parz/parsers
Values
pub fn digits() -> fn(String) -> Result(
types.ParserState(String),
String,
)
Utility parser for digits ^[0-9]+
pub fn letters() -> fn(String) -> Result(
types.ParserState(String),
String,
)
Utility parser for letters ^[A-Za-z]+
pub fn regex(
re_str: String,
) -> fn(String) -> Result(types.ParserState(String), String)
Create a parser that matches a string using a regex
pub fn str(
start: String,
) -> fn(String) -> Result(types.ParserState(String), String)
Create a parser that matches a fixed string literal
pub fn whitespace() -> fn(String) -> Result(
types.ParserState(String),
String,
)
Utility parser for whitespace ^\s*